@@ -17,15 +17,9 @@ from .utk_face import vgg_utk_face, vgg_utk_face_pretrained
 from .detection import yolo_base, yolo_widerface_pretrained, yolo_voc_pretrained
 from .centernet import centernet_base, centernet_voc_pretrained
 from .mnist import gxnor_mnist, gxnor_mnist_pretrained
-from .transformers import (vit_imagenet, vit_ti16, bc_vit_ti16,  bc_vit_ti16_imagenet_pretrained,
-                           vit_s16, vit_s32, vit_b16, vit_b32, vit_l16, vit_l32, deit_imagenet,
-                           deit_ti16, bc_deit_ti16, bc_deit_dist_ti16_imagenet_pretrained, deit_s16,
-                           deit_b16)
 from .portrait128 import akida_unet_portrait128, akida_unet_portrait128_pretrained
-from .urbansound import vit_urbansound_pretrained
 from .tenn_spatiotemporal import (tenn_spatiotemporal_dvs128, tenn_spatiotemporal_dvs128_pretrained,
                                   tenn_spatiotemporal_eye, tenn_spatiotemporal_eye_pretrained,
                                   tenn_spatiotemporal_jester, tenn_spatiotemporal_jester_pretrained)
-
 from .utils import fetch_file
 from .model_io import load_model
