@@ -20,11 +20,12 @@ This module defines a custom loss function for CenterNet training
 
 __all__ = ["CenternetLoss"]
 
-from keras import backend as K
+from tf_keras import backend as K
 import tensorflow as tf
+import tf_keras as keras
 
 
-class CenternetLoss(tf.keras.losses.Loss):
+class CenternetLoss(keras.losses.Loss):
     """ Computes CenterNet loss from a model raw output.
 
     The CenterNet loss computation is from https://arxiv.org/abs/1904.07850.
@@ -45,8 +46,9 @@ class CenternetLoss(tf.keras.losses.Loss):
                  eps=1e-12,
                  heatmap_loss_weight=1.0,
                  wh_loss_weight=0.1,
-                 offset_loss_weight=1.0):
-        super().__init__()
+                 offset_loss_weight=1.0,
+                 **kwargs):
+        super().__init__(**kwargs)
         # Parameters for the gaussian focal loss for the heatmap branch
         self._alpha = alpha
         self._gamma = gamma
