@@ -38,8 +38,6 @@ from .imagenet.model_akidanet18 import akidanet18_imagenet
 from .detection.model_yolo import yolo_base
 from .dvs.model_convtiny import convtiny_dvs
 from .mnist.model_gxnor import gxnor_mnist
-from .transformers.model_vit import vit_ti16, bc_vit_ti16
-from .transformers.model_deit import deit_ti16, bc_deit_ti16
 from .portrait128.model_akida_unet import akida_unet_portrait128
 from .centernet.model_centernet import centernet_base
 from .sparsity import compute_sparsity
@@ -82,43 +80,6 @@ def load_model_weights(model_path, weights_path):
     print(f"Saved model with new weights to {model_path}.")
 
 
-def add_transformers_args(parser, add_customs=False, default_norm='LN', default_act='GeLU'):
-    """ Add transformers commons arguments to the given parser.
-
-    Args:
-        parser (argparse.ArgumentParser): parser to add args to
-        add_customs (bool, optional): indicates if normalization, softmax,
-            last normalization and activation can be customized. Defaults to
-            False.
-        default_norm (str, optional): when add_customs=True, default value for normalization.
-            Defaults to 'LN'.
-        default_act (str, optional): when add_customs=True, default value for activation. Defaults
-            to 'GeLU'.
-    """
-    parser.add_argument("-c", "--classes", type=int, default=1000,
-                        help="The number of classes, by default %(default)s.")
-    parser.add_argument("-bw", "--base_weights", type=str, default=None,
-                        help="Optional keras weights to load in the model, by default %(default)s.")
-    if add_customs:
-        norms = ['LN', 'GN1', 'BN', 'LMN']
-        parser.add_argument("--norm", type=str, choices=norms, default=default_norm,
-                            help="Replace normalization in model with a custom function, by \
-                                  default %(default)s")
-        last_norms = ['LN', 'BN']
-        parser.add_argument("--last_norm", type=str, choices=last_norms,
-                            default=default_norm,
-                            help=f"Replace last normalization in model with a \
-                                  custom function, by default {default_norm}")
-        sms = ['softmax', 'softmax2']
-        parser.add_argument("--softmax", type=str, choices=sms, default='softmax',
-                            help="Replace softmax operation in model with custom function, by \
-                                  default %(default)s")
-        acts = ['GeLU', 'ReLU8', 'swish']
-        parser.add_argument("--act", type=str, choices=acts, default=default_act,
-                            help="Replace activation function in model with custom function, \
-                                  by default %(default)s")
-
-
 def add_common_args(parser, default_classes, default_alpha=None, default_img_size=None,
                     bw_required=None):
     """ Add commons arguments to the given parser.
@@ -179,13 +140,9 @@ def main():
                                   help="The type of model to be instantiated")
     csp.add_parser("vgg_utk_face", help="A VGG-like UTKFace model")
 
-    dvsh_parser = csp.add_parser("convtiny_dvs_handy",
-                                 help="A Convtiny DVS handy model")
-    add_common_args(dvsh_parser, default_classes=9)
+    csp.add_parser("convtiny_dvs_handy", help="A Convtiny DVS handy model")
 
-    dvsg_parser = csp.add_parser("convtiny_dvs_gesture",
-                                 help="A Convtiny DVS gesture model")
-    add_common_args(dvsg_parser, default_classes=10)
+    csp.add_parser("convtiny_dvs_gesture", help="A Convtiny DVS gesture model")
 
     csp.add_parser(
         "ds_cnn_kws",
@@ -212,9 +169,7 @@ def main():
     an18_parser = csp.add_parser("akidanet18_imagenet", help="An AkidaNet18 model")
     add_common_args(an18_parser, default_classes=1000, default_img_size=224)
 
-    pnet_parser = csp.add_parser("pointnet_plus_modelnet40",
-                                 help="A PointNet++ model for Akida")
-    add_common_args(pnet_parser, default_classes=40)
+    pnet_parser = csp.add_parser("pointnet_plus_modelnet40", help="A PointNet++ model for Akida")
     pnet_parser.add_argument("-alpha",
                              "--alpha",
                              type=float,
@@ -243,44 +198,16 @@ def main():
                            choices=[224, 384],
                            help="The square input image size")
 
-    dvst_parser = csp.add_parser("tenn_spatiotemporal_dvs128",
-                                 help="A TENN spatiotemporal model for DVS128")
-    add_common_args(dvst_parser, default_classes=10)
+    csp.add_parser("tenn_spatiotemporal_dvs128",
+                   help="A TENN spatiotemporal model for DVS128")
 
     eye_p = csp.add_parser("tenn_spatiotemporal_eye",
                            help="A TENN spatiotemporal model for AIS2024 event-based eyetracking")
     eye_p.add_argument("-reg", "--reg_factor", type=float, default=1e-8,
                        help="The regularization factor, default %(default)s.")
 
-    jester_parser = csp.add_parser("tenn_spatiotemporal_jester",
-                                   help="A TENN spatiotemporal model for jester video.")
-    add_common_args(jester_parser, default_classes=27)
-
-    vit_parser = csp.add_parser("vit_ti16", help="A ViT model")
-    add_transformers_args(vit_parser, add_customs=True)
-    vit_parser.add_argument("-i", "--image_size", type=int, default=224,
-                            choices=[224, 384], help="The square input image size")
-
-    bc_vit_parser = csp.add_parser("bc_vit_ti16", help="A ViT, brainchip customized model")
-    add_transformers_args(bc_vit_parser)
-    bc_vit_parser.add_argument("-b", "--blocks", type=int, default=12,
-                               help="Number of transformer blocks")
-
-    deit_parser = csp.add_parser("deit_ti16", help="A DeiT model")
-    add_transformers_args(deit_parser, add_customs=True)
-    deit_parser.add_argument("-i", "--image_size", type=int, default=224,
-                             choices=[160, 224], help="The square input image size")
-    deit_parser.add_argument("-d", "--dist", action="store_true",
-                             help="Use the model with a distilled token")
-
-    bc_deit_parser = csp.add_parser("bc_deit_ti16", help="A DeiT, brainchip customized model")
-    add_transformers_args(bc_deit_parser)
-    bc_deit_parser.add_argument("-d", "--dist", action="store_true",
-                                help="Use the model with a distilled token")
-    bc_deit_parser.add_argument("-b", "--blocks", type=int, default=12,
-                                help="Number of transformer blocks")
-
-    csp.add_parser("vit_urbansound", help="An audio ViT, brainchip customized model")
+    csp.add_parser("tenn_spatiotemporal_jester",
+                   help="A TENN spatiotemporal model for jester video.")
 
     sparsity_parser = sp.add_parser("sparsity", help="Compute the sparsity of the model")
     sparsity_parser.add_argument("-m", "--model", type=str,
@@ -322,14 +249,13 @@ def main():
         if args.model == "vgg_utk_face":
             model = vgg_utk_face()
         elif args.model == "convtiny_dvs_handy":
-            model = convtiny_dvs(input_shape=(120, 160, 2), classes=args.classes)
+            model = convtiny_dvs(input_shape=(120, 160, 2), classes=9)
         elif args.model == "convtiny_dvs_gesture":
-            model = convtiny_dvs(input_shape=(64, 64, 10), classes=args.classes)
+            model = convtiny_dvs(input_shape=(64, 64, 10))
         elif args.model == "ds_cnn_kws":
             model = ds_cnn_kws()
         elif args.model == "pointnet_plus_modelnet40":
-            model = pointnet_plus_modelnet40(alpha=args.alpha,
-                                             classes=args.classes)
+            model = pointnet_plus_modelnet40(alpha=args.alpha)
         elif args.model == "mobilenet_imagenet":
             input_shape = (args.image_size, args.image_size, 3)
             model = mobilenet_imagenet(input_shape,
@@ -370,36 +296,6 @@ def main():
             model = tenn_spatiotemporal_eye(reg_factor=args.reg_factor)
         elif args.model == "tenn_spatiotemporal_jester":
             model = tenn_spatiotemporal_jester()
-        elif args.model == "vit_urbansound":
-            # Create a base ViT model with 10 classes and 1 transformer block
-            model = bc_vit_ti16(input_shape=(224, 224, 1), classes=10, num_blocks=1)
-        else:
-            # Handle transformer models
-            if args.model == "vit_ti16":
-                input_shape = (args.image_size, args.image_size, 3)
-                model = vit_ti16(input_shape=input_shape,
-                                 classes=args.classes,
-                                 norm=args.norm,
-                                 last_norm=args.last_norm,
-                                 softmax=args.softmax,
-                                 act=args.act)
-            elif args.model == "bc_vit_ti16":
-                model = bc_vit_ti16(classes=args.classes, num_blocks=args.blocks)
-            elif args.model == "deit_ti16":
-                input_shape = (args.image_size, args.image_size, 3)
-                model = deit_ti16(input_shape=input_shape,
-                                  classes=args.classes,
-                                  distilled=args.dist,
-                                  norm=args.norm,
-                                  last_norm=args.last_norm,
-                                  softmax=args.softmax,
-                                  act=args.act)
-            elif args.model == "bc_deit_ti16":
-                model = bc_deit_ti16(classes=args.classes, distilled=args.dist,
-                                     num_blocks=args.blocks)
-            # Load provided weights
-            if args.base_weights is not None:
-                model.load_weights(args.base_weights, by_name=True)
         # No need for default behaviour as the command-line parser only accepts
         # valid model types
         model_path = args.save_model
