@@ -17,9 +17,15 @@
 """
 This module provides some utils to handle boxes and calculate the jaccard overlap score.
 """
+
+__all__ = ["xywh_to_xyxy", "xyxy_to_xywh", "compute_center_xy",
+           "compute_center_wh", "compute_overlap"]
+
 import numpy as np
 import tensorflow as tf
 
+from .data_utils import Coord
+
 
 def xywh_to_xyxy(boxes):
     """Convert a set of boxes from format xywh to xyxy, where each format represent:
@@ -28,10 +34,10 @@ def xywh_to_xyxy(boxes):
         * 'xyxy': format of ('x_min', 'y_min', 'x_max', 'y_max'), also called 'corners'.
 
     Args:
-        boxes (tf.tensor or np.ndarray): tensor with shape (N, 4)
+        boxes (tf.Tensor or np.ndarray): tensor with shape (N, 4)
 
     Returns:
-        tf.tensor or np.ndarray: tensor with new format
+        tf.Tensor or np.ndarray: tensor with new format
     """
     assert boxes.shape[-1] == 4, "Expected 4 as last dimension."
     x1y1 = boxes[..., :2] - 0.5 * boxes[..., -2:]
@@ -48,10 +54,10 @@ def xyxy_to_xywh(boxes):
         * 'xywh': format of ('cx', 'xy', 'w', 'h'), also called 'centroids'.
 
     Args:
-        boxes (tf.tensor): tensor with shape (N, 4)
+        boxes (tf.Tensor): tensor with shape (N, 4)
 
     Returns:
-        tf.tensor: tensor with new format
+        tf.Tensor: tensor with new format
     """
     assert boxes.shape[-1] == 4, "Expected 4 as last dimension."
     tf.debugging.assert_greater_equal(boxes[..., -2:], boxes[..., :2],
@@ -63,6 +69,42 @@ def xyxy_to_xywh(boxes):
     return np.concatenate([xy, wh], axis=-1)
 
 
+def compute_center_xy(bbox, grid_size):
+    """
+    Computes the center coordinates (x, y) of a bounding box relative to the grid.
+
+    Args:
+        bbox (tf.Tensor): Bounding box coordinates (ymin, xmin, ymax, xmax).
+        grid_size (tuple): The grid size in the format (h, w).
+
+    Returns:
+        tuple: A tuple containing the center coordinates (center_x, center_y).
+    """
+    center_x = .5 * (bbox[Coord.x1] + bbox[Coord.x2])
+    center_x = center_x * grid_size[1]
+
+    center_y = .5 * (bbox[Coord.y1] + bbox[Coord.y2])
+    center_y = center_y * grid_size[0]
+
+    return center_x, center_y
+
+
+def compute_center_wh(bbox, grid_size):
+    """
+    Computes the width and height of a bounding box relative to a grid.
+
+    Args:
+        bbox (tf.Tensor): Bounding box coordinates (ymin, xmin, ymax, xmax).
+        grid_size (tuple): The grid size in the format (h, w).
+
+    Returns:
+        tuple: The width and height of the bounding box.
+    """
+    center_h = (bbox[Coord.y2] - bbox[Coord.y1]) * grid_size[0]
+    center_w = (bbox[Coord.x2] - bbox[Coord.x1]) * grid_size[1]
+    return center_w, center_h
+
+
 def compute_overlap(a1, a2, mode="element_wise", box_format="xywh"):
     """Calculate ious between a1, a2 in two different modes:
 
@@ -70,13 +112,15 @@ def compute_overlap(a1, a2, mode="element_wise", box_format="xywh"):
         * outer_product: compute cross iou with all possible combination between inputs.
 
     Args:
-        a1 (tf.tensor or np.ndarray): set of boxes, with shape at least equal to (N, 4).
-        a2 (tf.tensor or np.ndarray): set of boxes, with compatible broadcast-shape
+        a1 (tf.Tensor or np.ndarray): set of boxes, with shape at least equal to (N, 4).
+        a2 (tf.Tensor or np.ndarray): set of boxes, with compatible broadcast-shape
             (in 'element_wise' mode) or shape at least equal to (N, 4) (in 'outer_product' mode).
+        mode (str, optional): the mode to use. 'element_wise' or 'outer_product'. Defaults to
+            "element_wise".
         box_format (str, optional): format of both inputs. Defaults to 'xywh'.
 
     Returns:
-        tf.tensor or np.ndarray: IoU between inputs with shape (N,) in 'element_wise',
+        tf.Tensor or np.ndarray: IoU between inputs with shape (N,) in 'element_wise',
         otherwise (N, M).
     """
     format_choices = ["xywh", "xyxy"]
