@@ -21,8 +21,7 @@ __all__ = ['augment_sample', 'build_yolo_aug_pipeline', 'init_random_vars']
 
 import cv2
 import numpy as np
-# monkey patch for imgaug that uses a deprecated np.bool type that will raise an error
-np.bool = bool
+
 from imgaug import augmenters as iaa
 from imgaug.augmentables.bbs import BoundingBoxesOnImage, BoundingBox as BoundingBoxAug
 
@@ -69,7 +68,7 @@ def augment_sample(image, objects, aug_pipe, labels, flip, scale, offx, offy):
 
 def _objects_to_bbox(objects, labels, image_shape):
     """
-    Transforms objects bounding boxes from numpy array to BoundingBox format from imgaug library.
+    Transforms objects bounding boxes from numpy array to BoundingBox format from imaug library.
 
     Args:
         objects (dict): dictionary containing information about objects in the image,
@@ -78,7 +77,7 @@ def _objects_to_bbox(objects, labels, image_shape):
         image_shape (tuple): the shape of the image on which the objects are placed.
 
     Returns:
-        BoundingBoxesOnImage: BoundingBoxesOnImage object from imgaug library containing
+        BoundingBoxesOnImage: BoundingBoxesOnImage object from imaug library containing
             bounding boxes coordinates with their label.
     """
     boxes = objects['bbox']
@@ -94,11 +93,11 @@ def _objects_to_bbox(objects, labels, image_shape):
 
 def _bbox_to_objects(boxes, labels):
     """
-    Extracts bounding boxes from imgaug objects to a dictionary containing
+    Extracts bounding boxes from imaug objects to a dictionary containing
         bounding box coordinates and corresponding labels.
 
     Args:
-        boxes (list): list of imgaug bounding boxes.
+        boxes (list): list of imaug bounding boxes.
         labels (list): list of labels of interest.
 
     Returns:
@@ -197,7 +196,7 @@ def build_yolo_aug_pipeline():
     Returns:
         iaa.Sequential: sequence of augmentation.
     """
-    # augmentors by https://github.com/aleju/imgaug
+    # augmentors by https://github.com/imaug/imaug
     def sometimes(aug): return iaa.Sometimes(0.5, aug)
 
     # All augmenters with per_channel=0.5 will sample one value per
