@@ -20,12 +20,11 @@ Module used to compute mAP scores for YOLO classification.
 
 __all__ = ["MapEvaluation"]
 
-import keras
+import tf_keras as keras
 import numpy as np
-import tensorflow as tf
 
 from collections import defaultdict
-from keras.src.utils import io_utils
+from tf_keras.src.utils import io_utils
 from .processing import decode_output, desize_bboxes, get_affine_transform, preprocess_image
 from .box_utils import compute_overlap
 from .data_utils import Coord
@@ -146,7 +145,7 @@ class MapEvaluation(keras.callbacks.Callback):
                 mean_avgs[label] += ap / total_iterations
             self._pbar.update(1)
         self._pbar.close()
-        tf.keras.backend.clear_session()
+        keras.backend.clear_session()
 
         return map_dict, mean_avgs
 
@@ -187,12 +186,11 @@ class MapEvaluation(keras.callbacks.Callback):
                                                         input_shape[0]])
 
             image = preprocess_image(raw_image.numpy(), input_shape, affine_transform)
+            input_image = image[np.newaxis, :]
 
             if self._is_keras_model:
-                input_image = image[np.newaxis, :]
                 output = self._model.predict(input_image, verbose=0)[0]
             else:
-                input_image = image[np.newaxis, :].astype(np.uint8)
                 potentials = self._model.predict(input_image)[0]
 
                 if self._anchors:
