@@ -205,12 +205,11 @@ def preprocess_image(image, input_shape, affine_transform=None):
         image = cv2.warpAffine(image, affine_transform, (input_shape[1], input_shape[0]),
                                flags=cv2.INTER_LINEAR)
     else:
-        image = tf.compat.v1.image.resize(image, [input_shape[0], input_shape[1]],
-                                          method=tf.image.ResizeMethod.BILINEAR,
-                                          align_corners=False)
+        image = tf.image.resize(image, [input_shape[0], input_shape[1]],
+                                method=tf.image.ResizeMethod.BILINEAR)
         image = image.numpy()
 
-    return image
+    return image.astype(np.uint8)
 
 
 def apply_affine_transform_to_bboxes(bboxes, affine_transform):
