@@ -21,13 +21,8 @@ Load VOC dataset
 __all__ = ["get_voc_dataset"]
 
 import os
-
 import tensorflow as tf
-
-try:
-    import tensorflow_datasets as tfds
-except ImportError:
-    tfds = None
+import tensorflow_datasets as tfds
 
 from ..data_utils import get_dataset_length, remove_empty_objects
 
@@ -46,31 +41,32 @@ def get_voc_dataset(data_path, labels=["car", "person"], training=False):
         tf.dataset, labels (list[str]), int: the requested dataset (train or validation), the
         list of labels and the dataset size.
     """
+    if data_path:
+        write_dir = os.path.join(data_path, 'tfds')
 
-    assert tfds is not None, "To load voc dataset, tensorflow-datasets module must\
-        be installed."
+        download_and_prepare_kwargs = {
+            'download_config': tfds.download.DownloadConfig(manual_dir=data_path)
+        }
 
-    write_dir = os.path.join(data_path, 'tfds')
+        tfrecords_path = os.path.join(write_dir, 'data', 'voc')
+        if not os.path.exists(tfrecords_path):
+            _check_zip_files(data_path)
 
-    download_and_prepare_kwargs = {
-        'download_config': tfds.download.DownloadConfig(manual_dir=data_path)
-    }
-
-    tfrecords_path = os.path.join(write_dir, 'data', 'voc')
-    if not os.path.exists(tfrecords_path):
-        _check_zip_files(data_path)
+        data_dir = os.path.join(write_dir, 'data')
+    else:
+        data_dir = None
+        download_and_prepare_kwargs = {}
 
     split = 'train+validation' if training else 'test'
-    data_dir = os.path.join(write_dir, 'data')
 
     if training:
-        (dataset12), infos = tfds.load("voc/2012:4.0.0",
+        (dataset12), infos = tfds.load("voc/2012",
                                        split=split,
                                        with_info=True,
                                        data_dir=data_dir,
                                        shuffle_files=training,
                                        download_and_prepare_kwargs=download_and_prepare_kwargs)
-        (dataset07), _ = tfds.load("voc/2007:4.0.0",
+        (dataset07), _ = tfds.load("voc/2007",
                                    split=split,
                                    with_info=True,
                                    data_dir=data_dir,
@@ -78,7 +74,7 @@ def get_voc_dataset(data_path, labels=["car", "person"], training=False):
                                    download_and_prepare_kwargs=download_and_prepare_kwargs)
         dataset = dataset12.concatenate(dataset07)
     else:
-        dataset, infos = tfds.load("voc/2007:4.0.0",
+        dataset, infos = tfds.load("voc/2007",
                                    split=split,
                                    with_info=True,
                                    data_dir=data_dir,
