@@ -23,7 +23,7 @@ __all__ = ["YoloLoss"]
 import numpy as np
 import tensorflow as tf
 
-from keras import backend as K
+from tf_keras import backend as K
 
 from .box_utils import compute_overlap
 
