@@ -24,9 +24,9 @@ import pickle
 
 import numpy as np
 from cnn2snn import convert
-from keras import Model
-from keras.callbacks import EarlyStopping
-from keras.layers import Reshape
+from tf_keras import Model
+from tf_keras.callbacks import EarlyStopping
+from tf_keras.layers import Reshape
 
 from ..extract import extract_samples
 from ..model_io import load_model
@@ -110,7 +110,7 @@ def train(model, train_data, valid_data, num_train, num_valid, anchors, labels,
                                      num_valid,
                                      labels,
                                      anchors,
-                                     period=1,
+                                     period=5,
                                      obj_threshold=obj_threshold,
                                      nms_threshold=nms_threshold)
 
@@ -202,7 +202,6 @@ def main():
     global_parser.add_argument(
         "-d",
         "--data",
-        required=True,
         help="The directory containing VOC, WiderFace or COCO data.")
     global_parser.add_argument(
         "dataset_name",
