@@ -22,8 +22,9 @@ import os
 import argparse
 import numpy as np
 import tensorflow as tf
+import tf_keras as keras
 
-from keras.utils import to_categorical
+from tf_keras.utils import to_categorical
 
 from cnn2snn import convert
 
@@ -35,7 +36,7 @@ from ..utils import fetch_file
 from ..model_io import load_model
 
 
-def get_data(dataset, batch_size):
+def get_data(dataset, batch_size, dtype=tf.int8):
     """ Loads data.
 
     Dataset parameters for DVSDataGenerator are set from DVS pickles.
@@ -44,11 +45,17 @@ def get_data(dataset, batch_size):
         dataset (str): name of the dataset to load, either 'dvs_gesture' or
             'samsung_handy'.
         batch_size (int): the batch size
+        dtype (tf.dtypes.DType): input data type. Defaults to tf.int8.
 
     Returns:
         tf.dataset, tf.dataset, int: train dataset, test dataset and number of
         samples.
     """
+    def cast_data(image, label):
+        image = tf.cast(image, dtype)
+        label = tf.cast(label, tf.int32)
+        return image, label
+
     # Load pre-processed dataset
     train_file = fetch_file(os.path.join('https://data.brainchip.com/dataset-mirror',
                                          dataset, dataset + '_preprocessed_train.npz'),
@@ -70,16 +77,19 @@ def get_data(dataset, batch_size):
     train_dataset = tf.data.Dataset.from_tensor_slices((x_train, y_train))
     test_dataset = tf.data.Dataset.from_tensor_slices((x_test, y_test))
 
-    data_augmentation = tf.keras.Sequential([
-        tf.keras.layers.RandomRotation(0.05, interpolation='nearest'),
+    data_augmentation = keras.Sequential([
+        keras.layers.RandomRotation(0.05, interpolation='nearest'),
     ])
 
     train_dataset = train_dataset.shuffle(
         buffer_size=1024).batch(batch_size).map(
             lambda x, y: (data_augmentation(x, training=True), y),
-            num_parallel_calls=tf.data.AUTOTUNE).prefetch(
+            num_parallel_calls=tf.data.AUTOTUNE).map(
+                cast_data, num_parallel_calls=tf.data.AUTOTUNE).prefetch(
                 buffer_size=tf.data.AUTOTUNE)
-    test_dataset = test_dataset.batch(batch_size).prefetch(
+
+    test_dataset = test_dataset.batch(batch_size).map(
+        cast_data, num_parallel_calls=tf.data.AUTOTUNE).prefetch(
         buffer_size=tf.data.AUTOTUNE)
 
     return train_dataset, test_dataset, x_train.shape[0]
