@@ -21,9 +21,9 @@ constraint.
 
 import warnings
 
-from keras.models import clone_model
-from keras.utils import custom_object_scope
-from keras.layers import BatchNormalization
+from tf_keras.models import clone_model
+from tf_keras.utils import custom_object_scope
+from tf_keras.layers import BatchNormalization
 
 from cnn2snn.min_value_constraint import MinValueConstraint
 
@@ -59,7 +59,7 @@ def add_gamma_constraint(model):
             if layer.gamma_constraint is not None:
                 warnings.warn(
                     f"Layer {layer.name} already has a gamma_constraint set "
-                    f"to {layer.gamma_constraint}, it will be overwritten.")
+                    f"to {layer.gamma_constraint}, it will be overwritten. Continuing execution.")
             bn = BatchNormalization.from_config(layer.get_config())
             bn.gamma_constraint = constraint
             return bn
