@@ -24,36 +24,32 @@ import argparse
 
 import numpy as np
 import tensorflow as tf
-try:
-    import tensorflow_datasets as tfds
-except ImportError:
-    tfds = None
+import tensorflow_datasets as tfds
 
-import keras
-from keras.callbacks import LearningRateScheduler
-from keras import Sequential
-from keras.optimizers import SGD
-from keras.optimizers.legacy import Adam
-from keras.layers import Input
-from keras.models import clone_model
+
+import tf_keras as keras
+from tf_keras.callbacks import LearningRateScheduler
+from tf_keras import Sequential
+from tf_keras.optimizers import SGD
+from tf_keras.optimizers.legacy import Adam
+from tf_keras.layers import Input
+from tf_keras.models import clone_model
 
 import akida
 from cnn2snn import convert
-from quantizeml.layers import AddPositionEmbs, ClassToken
 
 from .preprocessing import preprocess_image, DATA_AUGMENTATION
 from ..training import (get_training_parser, freeze_model_before, print_history_stats, RestoreBest,
                         save_model)
 from ..extract import extract_samples
-from ..transformers.model_vit import apply_embedding_weights
-from ..distiller import DeitDistiller
 from ..param_scheduler import get_cosine_lr_scheduler
 from ..optimizers import LAMB
 from ..utils import get_tensorboard_callback
 from ..model_io import load_model
 
 
-def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=True, one_hot=False):
+def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=True, one_hot=False,
+                         dtype=tf.uint8):
     """ Loads ImageNet 2012 dataset and builds a tf.dataset out of it.
 
     Args:
@@ -63,13 +59,18 @@ def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=T
         batch_size (int): the batch size
         data_aug (bool, optional): True to apply data augmentation (only train). Defaults to True.
         one_hot (bool, optional): whether to one hot labels or not. Defaults to False.
+        dtype (tf.dtypes.DType, optional): input data type. Defaults to tf.uint8.
 
     Returns:
         tf.dataset, int: the requested dataset (train or validation) and the
         corresponding steps
     """
-    assert tfds is not None, "To load imagenet dataset, tensorflow-datasets module must\
-        be installed."
+
+    def cast_data(image, label):
+        image = tf.cast(image, dtype)
+        label = tf.cast(label, tf.int32)
+        return image, label
+
     # Build the dataset
     write_dir = os.path.join(data_path, 'tfds')
 
@@ -95,12 +96,15 @@ def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=T
 
     data_aug = DATA_AUGMENTATION if data_aug else None
     dataset = dataset.map(lambda image, label: (preprocess_image(
-        image, image_size, training, data_aug), label))
+        image, image_size, training, data_aug), label)).map(
+            cast_data, num_parallel_calls=tf.data.AUTOTUNE)
 
     # One hot encode labels if requested
     if one_hot:
         num_classes = infos.features["label"].num_classes
-        dataset = dataset.map(lambda image, label: (image, tf.one_hot(label, num_classes)))
+        dataset = dataset.map(
+            lambda image, label: (image, tf.one_hot(label, num_classes))).map(
+                cast_data, num_parallel_calls=tf.data.AUTOTUNE)
 
     dataset = dataset.batch(batch_size)
     dataset = dataset.prefetch(1)
@@ -113,14 +117,12 @@ def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=T
     return dataset, infos.splits[split].num_examples / batch_size
 
 
-def compile_model(model, optimizer="SGD", distiller_type="none"):
+def compile_model(model, optimizer="SGD"):
     """ Compiles the model.
 
     Args:
         model (keras.Model): the model to compile
         optimizer (str, optional): the optimizer to use. Defaults to "SGD".
-        distiller_type (str, optional): string to select the loss in distillation.
-            Only used when input model is of ``DeitDistiller`` type. Defaults to 'none'.
 
     Returns:
         bool: True if labels should be one-hot encoded, False if not.
@@ -138,13 +140,6 @@ def compile_model(model, optimizer="SGD", distiller_type="none"):
             raise ValueError(f"Unknown optimizer {optim_str}. "
                              "Please choose one of these options: {SGD, ADAM, LAMB}")
 
-    if isinstance(model, DeitDistiller):
-        model.compile(optimizer=_get_optim(optimizer),
-                      metrics=['accuracy', 'top_k_categorical_accuracy'],
-                      student_loss_fn=keras.losses.CategoricalCrossentropy(from_logits=True),
-                      distiller_type=distiller_type)
-        return True
-
     model.compile(optimizer=_get_optim(optimizer),
                   loss=keras.losses.CategoricalCrossentropy(from_logits=True),
                   metrics=['accuracy', 'top_k_categorical_accuracy'])
@@ -183,7 +178,7 @@ def evaluate(model, val_dataset, batch_size, num_samples, val_steps):
             log_samples = num_samples
         while cur_samples < num_samples:
             x, y = next(it)
-            y_ak = model.predict_classes(x.astype(np.uint8))
+            y_ak = model.predict_classes(x)
             correct_preds += np.sum(y_ak == np.argmax(y, -1))
             cur_samples += y_ak.shape[0]
             if cur_samples % log_samples == 0 and cur_samples < num_samples:
@@ -197,7 +192,7 @@ def evaluate(model, val_dataset, batch_size, num_samples, val_steps):
         print(history)
 
 
-def rescale_legacy(base_model, input_size):
+def rescale(base_model, input_size):
     """ Rescales the model by changing its input size.
 
     Args:
@@ -207,9 +202,15 @@ def rescale_legacy(base_model, input_size):
     Returns:
         keras.Model: the rescaled model
     """
+    assert len(input_size) <= 2, f"Cannot rescale to {input_size}, only 2D array are supported."
+    if len(input_size) == 1:
+        input_size = (input_size[0], input_size[0])
+    else:
+        input_size = tuple(input_size)
+
     # Create the desired input
     input_shape = (input_size[0], input_size[1], base_model.input.shape[-1])
-    new_input = Input(input_shape)
+    new_input = Input(input_shape, dtype=tf.uint8)
 
     # Workaround to force the input shape update that is not working for
     # functional models: the input_tensors parameter is ignored as described in
@@ -225,81 +226,6 @@ def rescale_legacy(base_model, input_size):
     return clone
 
 
-def rescale_vit(base_model, input_size):
-    """ Rescales the model by changing its input size in three steps:
-        1. Change the input layer, given the new input size values
-        2. Reconstruct model from config
-        3. Update weights, taking into account interpolation on PosEmbed layer
-
-    Args:
-        base_model (keras.Model): the model to rescale
-        input_size (tuple): desired model input size
-
-    Returns:
-        keras.Model: the rescaled model
-    """
-    # 1. Create the desired input layer:
-    input_shape = (None, input_size[0], input_size[1], base_model.input.shape[-1])
-    num_tokens = sum(isinstance(ly, ClassToken) for ly in base_model.layers)
-
-    # 2. Clone the model by modification of dict_config:
-    # In models based on vision transformers, PositionEmbeding change its amount of parameters
-    # given an input size. This is why we need to reconstruct the model.
-    x_patch, y_patch = None, None
-    clone_config = base_model.get_config()
-
-    for layer_config in clone_config["layers"]:
-        # 2.1. Change input size
-        if layer_config["class_name"] == "InputLayer":
-            layer_config["config"]["batch_input_shape"] = input_shape
-        # 2.2. Recover total of patches in both directions
-        if "Conv2D" in layer_config["class_name"]:
-            x_patch = input_size[0] // layer_config["config"]["kernel_size"][0]
-            y_patch = input_size[1] // layer_config["config"]["kernel_size"][1]
-        # 2.3. Change values in reshape process
-        elif layer_config["class_name"] == "Reshape":
-            layer_config["config"]["target_shape"] = list(layer_config["config"]["target_shape"])
-            layer_config["config"]["target_shape"][0] = x_patch * y_patch
-        # Remove serialized build_config, otherwise from_config call that follows will build
-        # variables with the initial shape instead of the target shape
-        layer_config.pop('build_config', None)
-
-    # 2.5. Recompile model with new configuration
-    clone = base_model.from_config(clone_config)
-
-    # 3. Update weights:
-    # Get weights from based model, and tranfer them into clone model,
-    for base_layer, clone_layer in zip(base_model.layers, clone.layers):
-        base_weights = base_layer.get_weights()
-        if isinstance(base_layer, AddPositionEmbs):
-            apply_embedding_weights(clone_layer, base_weights, (x_patch, y_patch), num_tokens)
-        else:
-            clone_layer.set_weights(base_weights)
-    return clone
-
-
-def rescale(base_model, input_size):
-    """ Rescale the model by architecture (if there is a vision transformer model or not)
-
-    Args:
-        base_model (keras.Model): the model to rescale
-        input_size (list): desired model input size
-
-    Returns:
-        keras.Model: the rescaled model
-    """
-    assert len(input_size) <= 2, f"Cannot rescale to {input_size}, only 2D array are supported."
-    if len(input_size) == 1:
-        input_size = (input_size[0], input_size[0])
-    else:
-        input_size = tuple(input_size)
-
-    is_vit = any(isinstance(layer, AddPositionEmbs) for layer in base_model.layers)
-    if is_vit:
-        return rescale_vit(base_model, input_size)
-    return rescale_legacy(base_model, input_size)
-
-
 def train(model,
           train_dataset,
           train_steps,
@@ -455,14 +381,6 @@ def main():
                                    "['exp_decay', 'cosine_decay', 'cosine_sched'] which corresponds"
                                    " to exponential decay, cosine decay and cosine oscillation "
                                    "respectively.")
-    train_parser.add_argument("--teacher", type=str, default=None,
-                              help="Teacher model use to train the model through Knowledge"
-                              "Distillation. The input model output an Add layer. "
-                              "Defaults to %(default)s.")
-    train_parser.add_argument("-dt", "--distiller_type", type=str, default="soft",
-                              help="Define the distillation loss type. Defaults to %(default)s.")
-    train_parser.add_argument("-a", "--alpha", type=float, default=0.5,
-                              help="Value for distiller losses weighting. Defaults to %(default)s.")
 
     tune_parser = parsers[2]
     tune_parser.add_argument("-ie",
@@ -489,14 +407,6 @@ def main():
                                   "['exp_decay', 'cosine_decay', 'cosine_sched'] which corresponds "
                                   "to exponential decay, cosine decay and cosine oscillation "
                                   "respectively.")
-    tune_parser.add_argument("--teacher", type=str, default=None,
-                             help="Teacher model use to train the model through Knowledge"
-                             "Distillation. The input model output an Add layer. "
-                             "Defaults to %(default)s.")
-    tune_parser.add_argument("-dt", "--distiller_type", type=str, default="soft",
-                             help="Define the distillation loss type. Defaults to %(default)s.")
-    tune_parser.add_argument("-a", "--alpha", type=float, default=0.5,
-                             help="Value for distiller losses weighting. Defaults to %(default)s.")
 
     eval_parser = parsers[3]
     eval_parser.add_argument("-ns",
@@ -530,23 +440,12 @@ def main():
     model = load_model(args.model)
     im_size = model.input_shape[1:3]
 
-    # Try to load the teacher model, used after to train with Knowledge Distillation
-    # Hyperparameters takes from https://arxiv.org/pdf/2012.12877.pdf
-    if getattr(args, 'teacher', False):
-        if args.distiller_type not in ['none', 'soft', 'hard']:
-            raise ValueError("Distiller type must be one of ['none', 'soft', 'hard']")
-        teacher = load_model(args.teacher)
-        train_model = DeitDistiller(model, teacher, alpha=args.alpha, temperature=3.0)
-    else:
-        train_model = model
-
     # Freeze the model
     if "freeze_before" in args:
         freeze_model_before(model, args.freeze_before)
 
     # Compile model
-    one_hot = compile_model(train_model, optimizer=getattr(args, "optim", "SGD"),
-                            distiller_type=getattr(args, "distiller_type", "none"))
+    one_hot = compile_model(model, optimizer=getattr(args, "optim", "SGD"))
 
     # Load validation data
     if args.action in ['train', 'tune', 'eval']:
@@ -570,7 +469,7 @@ def main():
             # Tune learning rate following https://arxiv.org/pdf/2012.12877.pdf
             learning_rate *= args.batch_size / 512
 
-        train(train_model,
+        train(model,
               train_ds,
               train_steps,
               val_ds,
