@@ -49,7 +49,7 @@ def obtain_input_shape(input_shape, default_size, min_size, include_top):
         if input_shape[-1] not in {1, 3}:
             warnings.warn('This model usually expects 1 or 3 input channels. '
                           'However, it was passed an input_shape with ' +
-                          str(input_shape[-1]) + ' input channels.')
+                          str(input_shape[-1]) + ' input channels. Continuing execution.')
         default_shape = (default_size, default_size, input_shape[-1])
     else:
         default_shape = (default_size, default_size, 3)
