@@ -23,10 +23,12 @@ spike extractor and a classification layer.
 __all__ = ["akidanet_edge_imagenet", "akidanet_edge_imagenet_pretrained",
            "akidanet_faceidentification_edge_pretrained"]
 
-from keras import Model
-from keras.layers import Reshape
+import warnings
 
-from cnn2snn import quantize_layer
+from tf_keras import Model
+from tf_keras.layers import Reshape
+
+from cnn2snn import quantize_layer, get_akida_version, AkidaVersion
 
 from ..layer_blocks import separable_conv_block, dense_block
 from ..utils import fetch_file, get_params_by_version
@@ -44,6 +46,10 @@ def akidanet_edge_imagenet(base_model, classes, base_layer="classifier"):
     Returns:
         keras.Model: a Keras Model instance.
     """
+    if get_akida_version() != AkidaVersion.v1:
+        warnings.warn("Edge learning is only supported for Akida 1.0, the model will be created "
+                      "but will not be compatible with Akida 2.0.")
+
     if isinstance(base_model, str):
         base_model = load_model(base_model)
 
@@ -125,16 +131,11 @@ def akidanet_edge_imagenet_pretrained(quantized=True):
     if quantized:
         model_name_v1 = 'akidanet_imagenet_224_alpha_50_edge_iq8_wq4_aq4.h5'
         file_hash_v1 = '71ffc3acb09e5682e479505f6b288bd2736311ce46d3974bdf7b2c02916e52a8'
-        model_name_v2 = 'akidanet_imagenet_224_alpha_0.5_edge_i8_w8_a8.h5'
-        file_hash_v2 = '411ace11f534c51431458ed541c0f73b14e520f6787fb5a0b47f671510841aff'
     else:
         model_name_v1 = 'akidanet_imagenet_224_alpha_50_edge.h5'
         file_hash_v1 = '586ab1fb1baf9e171c54bbc6f4e7ef9fd6910bb5b169ef5b9dd5a29122683d31'
-        model_name_v2 = 'akidanet_imagenet_224_alpha_0.5_edge.h5'
-        file_hash_v2 = '9763ff8d95d2be88766339171c5ffb6f407f706802bb5939d39c87e5218521ed'
 
-    model_path, model_name, file_hash = get_model_path("akidanet_edge", model_name_v1, file_hash_v1,
-                                                       model_name_v2, file_hash_v2)
+    model_path, model_name, file_hash = get_model_path("akidanet_edge", model_name_v1, file_hash_v1)
     model_path = fetch_file(model_path,
                             fname=model_name,
                             file_hash=file_hash,
@@ -158,16 +159,11 @@ def akidanet_faceidentification_edge_pretrained(quantized=True):
     if quantized:
         model_name_v1 = 'akidanet_faceidentification_edge_iq8_wq4_aq4.h5'
         file_hash_v1 = '61838682cc88cec6dc9a347f1a301bfa9e94fbcbc7a52a273789259de07d3104'
-        model_name_v2 = 'akidanet_faceidentification_edge_i8_w8_a8.h5'
-        file_hash_v2 = '7f4b31cee430f04325ac3351a42ab9eedb0158b3706f57aa6f137e5b0291564b'
     else:
         model_name_v1 = 'akidanet_faceidentification_edge.h5'
         file_hash_v1 = 'fc0e6f06078dcafb503ec8944a871c781297bc120ef6335b17a17f6f8b316bbf'
-        model_name_v2 = 'akidanet_faceidentification_edge.h5'
-        file_hash_v2 = 'bc5054c3370c8194d27380df0f99c5ac285ce160d04c7776e665436668fe416f'
 
-    model_path, model_name, file_hash = get_model_path("akidanet_edge", model_name_v1, file_hash_v1,
-                                                       model_name_v2, file_hash_v2)
+    model_path, model_name, file_hash = get_model_path("akidanet_edge", model_name_v1, file_hash_v1)
     model_path = fetch_file(model_path,
                             fname=model_name,
                             file_hash=file_hash,
