@@ -20,7 +20,7 @@ Preprocessing tools for ImageNet dataset.
 __all__ = ["RandomColorJitter", "ThreeAugment", "preprocess_image", "index_to_label"]
 
 import numpy as np
-import keras
+import tf_keras as keras
 import tensorflow as tf
 from scipy.ndimage import gaussian_filter
 
