@@ -20,8 +20,10 @@ KWS model training script.
 
 import os
 import pickle
+import warnings
+import numpy as np
 
-from keras.utils import to_categorical
+from tf_keras.utils import to_categorical
 
 from cnn2snn import quantize_layer, convert
 
@@ -33,9 +35,12 @@ from ..utils import fetch_file
 from ..model_io import load_model
 
 
-def get_data():
+def get_data(dtype='uint8'):
     """ Loads KWS data.
 
+    Args:
+        dtype (str, optional): input data type. Defaults to 'uint8'.
+
     Returns:
         tuple: train data, train labels, validation data and validation labels
     """
@@ -49,7 +54,8 @@ def get_data():
     with open(fname, 'rb') as f:
         [x_train, y_train, x_val, y_val, _, _, _, _] = pickle.load(f)
 
-    return x_train.astype('float32'), y_train, x_val.astype('float32'), y_val
+    return (x_train.astype(dtype), y_train.astype(np.int32), x_val.astype(dtype),
+            y_val.astype(np.int32))
 
 
 def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
@@ -66,8 +72,8 @@ def train_model(model, x_train, y_train, x_val, y_val, batch_size, epochs):
     """
     # Warn user if number of epochs is not a multiple of 8
     if epochs % 8:
-        print("WARNING: for better performance, the number of epochs "
-              f" must be a multiple of 8; got 'epochs' = {epochs}")
+        warnings.warn("For better performance, the number of epochs must be a multiple of 8, "
+                      f" got 'epochs' = {epochs}. Continuing execution.")
 
     # Training parameters (cyclical learning rate)
     scaler = 4
@@ -134,7 +140,7 @@ def main():
         # Evaluate model accuracy
         if args.akida:
             model_ak = convert(model)
-            accuracy = model_ak.evaluate(x_val.astype('uint8'), y_val)
+            accuracy = model_ak.evaluate(x_val, y_val)
             print(f"Accuracy: {accuracy}")
         else:
             evaluate_model(model, x_val, y=to_categorical(y_val))
