@@ -20,6 +20,8 @@ Brainchip information:
       https://github.com/tensorflow/tensorflow/tree/master/tensorflow/examples/speech_commands
 """
 
+__all__ = ["AudioProcessor"]
+
 import hashlib
 import math
 import os.path
@@ -44,8 +46,8 @@ BACKGROUND_NOISE_DIR_NAME = '_background_noise_'
 RANDOM_SEED = 59185
 
 
-def prepare_model_settings(sample_rate, clip_duration_ms, window_size_ms,
-                           window_stride_ms, feature_bin_count):
+def _prepare_model_settings(sample_rate, clip_duration_ms, window_size_ms,
+                            window_stride_ms, feature_bin_count):
     """Calculates common settings needed for all models.
 
     Args:
@@ -83,7 +85,7 @@ def prepare_model_settings(sample_rate, clip_duration_ms, window_size_ms,
     }
 
 
-def prepare_words_list(wanted_words):
+def _prepare_words_list(wanted_words):
     """Prepends common tokens to the custom word list.
 
     Args:
@@ -95,7 +97,7 @@ def prepare_words_list(wanted_words):
     return [SILENCE_LABEL, UNKNOWN_WORD_LABEL] + wanted_words
 
 
-def which_set(filename, validation_percentage, testing_percentage):
+def _which_set(filename, validation_percentage, testing_percentage):
     """Determines which data partition the file should belong to.
 
     We want to keep files in the same training, validation, or testing sets even
@@ -161,11 +163,11 @@ class AudioProcessor():
                  testing_percentage=0):
         self.data_dir = None
         self.background_data = None
-        self.model_settings = prepare_model_settings(sample_rate,
-                                                     clip_duration_ms,
-                                                     window_size_ms,
-                                                     window_stride_ms,
-                                                     feature_bin_count)
+        self.model_settings = _prepare_model_settings(sample_rate,
+                                                      clip_duration_ms,
+                                                      window_size_ms,
+                                                      window_stride_ms,
+                                                      feature_bin_count)
         if data_dir:
             self.data_dir = data_dir
             self.maybe_download_and_extract_dataset(data_url, data_dir)
@@ -264,8 +266,8 @@ class AudioProcessor():
             if word == BACKGROUND_NOISE_DIR_NAME:
                 continue
             all_words[word] = True
-            set_index = which_set(wav_path, validation_percentage,
-                                  testing_percentage)
+            set_index = _which_set(wav_path, validation_percentage,
+                                   testing_percentage)
             # If it's a known class, store its detail, otherwise add it to the
             # list we'll use to train the unknown label.
             if word in wanted_words_index:
@@ -305,7 +307,7 @@ class AudioProcessor():
         for set_index in ['validation', 'testing', 'training']:
             random.shuffle(self.data_index[set_index])
         # Prepare the rest of the result data structure.
-        self.words_list = prepare_words_list(wanted_words)
+        self.words_list = _prepare_words_list(wanted_words)
         self.word_to_index = {}
         for word in all_words:
             if word in wanted_words_index:
