@@ -17,20 +17,17 @@
 """
 Layers blocks definitions.
 """
-from functools import partial
-
-from keras.layers import (BatchNormalization, ReLU, Conv2D, DepthwiseConv2D, SeparableConv2D, Dense,
-                          MaxPool2D, GlobalAvgPool2D, LayerNormalization, Dropout, Add,
-                          Conv2DTranspose, Reshape, Conv3D)
-from keras.activations import swish, gelu
-from keras.initializers import TruncatedNormal
-from keras.utils import register_keras_serializable
-import tensorflow as tf
 import numpy as np
+import tf_keras as keras
+import tensorflow as tf
+
+from tf_keras.layers import (BatchNormalization, ReLU, Conv2D, DepthwiseConv2D, SeparableConv2D,
+                             Dense, MaxPool2D, GlobalAvgPool2D, Conv2DTranspose, Conv3D)
+from tf_keras.activations import swish, gelu
+from tf_keras.utils import register_keras_serializable
 from scipy.special import jacobi
 
-from quantizeml.layers import (Attention, LayerMadNormalization, DepthwiseConv2DTranspose,
-                               ExtractToken)
+from quantizeml.layers import DepthwiseConv2DTranspose
 from .utils import get_params_by_version
 
 
@@ -288,142 +285,6 @@ def act_to_layer(act, **kwargs):
     return act_funct
 
 
-def norm_to_layer(norm):
-    """ Get normalization layer from string.
-
-    This is needed because one cannot serialize a class in layer.get_config, the string is thus
-    serialized instead.
-
-    Args:
-        norm (str): string that values in ['LN', 'GN1', 'BN', 'LMN'] and that allows to choose from
-            LayerNormalization, GroupNormalization(groups=1, ...), BatchNormalization or
-            LayerMadNormalization layers respectively in the model.
-
-    Returns:
-        keras.layers: the normalization layer class
-    """
-    if norm == 'LN':
-        norm_funct = LayerNormalization
-    elif norm == 'GN1':
-        norm_funct = partial(tf.keras.layers.GroupNormalization, groups=1)
-    elif norm == 'BN':
-        norm_funct = BatchNormalization
-    elif norm == 'LMN':
-        norm_funct = LayerMadNormalization
-    else:
-        raise NotImplementedError("norm should be in ['LN', 'GN1', 'BN', 'LMN']"
-                                  f" but received {norm}.")
-
-    return norm_funct
-
-
-def mlp_block(inputs, mlp_dim, dropout, name, mlp_act="GeLU"):
-    """ MLP block definition.
-
-    Args:
-        inputs (tf.Tensor): inputs
-        mlp_dim (int): number of units in the first dense layer
-        dropout (float): dropout rate
-        name (str): used as a base name for the layers in the block
-        mlp_act (str, optional): string that values in ['GeLU', 'ReLUx', 'swish'] and that allows to
-            choose from GeLU, ReLUx or swish activation. Defaults to "GeLU".
-
-    Returns:
-        tf.Tensor: MLP block outputs
-    """
-    initializer = {
-        "kernel_initializer": TruncatedNormal(stddev=0.02),
-        "bias_initializer": "zeros",
-    }
-    x = Dense(
-        mlp_dim,
-        name=f"{name}/Dense_0",
-        **initializer,
-    )(inputs)
-    x = act_to_layer(mlp_act, name=f"{name}/activation")(x)
-    x = Dropout(dropout)(x)
-    x = Dense(
-        inputs.shape[-1],
-        name=f"{name}/Dense_1",
-        **initializer,
-    )(x)
-    outputs = Dropout(dropout)(x)
-    return outputs
-
-
-def multi_head_attention(x, num_heads, hidden_size, name, softmax="softmax"):
-    """Multi-head attention block definition.
-
-    Args:
-        x (tf.Tensor): inputs
-        num_heads (int): the number of attention heads
-        hidden_size (int): query, key and value dense layers representation size (units)
-        name (str): used as a base name for the layers in the block
-        softmax (str, optional): string with values in ['softmax', 'softmax2'] that allows to choose
-            between softmax and softmax2 activation. Defaults to 'softmax'.
-
-    Raises:
-        ValueError: if hidden_size is not a multiple of num_heads
-
-    Returns:
-        (tf.Tensor, tf.Tensor): block outputs and attention softmaxed scores
-    """
-    if hidden_size % num_heads != 0:
-        raise ValueError(
-            f"Embedding dimension = {hidden_size} should be divisible "
-            f"by number of heads = {num_heads}"
-        )
-    initializer = {
-        "kernel_initializer": TruncatedNormal(stddev=0.02),
-        "bias_initializer": "zeros",
-    }
-    query = Dense(hidden_size, name=f"{name}/query", **initializer)(x)
-    key = Dense(hidden_size, name=f"{name}/key", **initializer)(x)
-    value = Dense(hidden_size, name=f"{name}/value", **initializer)(x)
-    attention, weights = Attention(num_heads=num_heads, softmax=softmax,
-                                   name=f"{name}/attention")([query, key, value])
-    output = Dense(hidden_size, name=f"{name}/out", **initializer)(attention)
-    return output, weights
-
-
-def transformer_block(inputs, num_heads, hidden_size, mlp_dim, dropout, name,
-                      norm='LN', softmax='softmax', mlp_act="GeLU"):
-    """Transformer block definition.
-
-    Args:
-        inputs (tf.Tensor): inputs
-        num_heads (int): the number of attention heads
-        hidden_size (int): multi-head attention block internal size
-        mlp_dim (int): MLP block internal size
-        dropout (float): dropout rate
-        name (str): used as a base name for the layers in the block
-        norm (str, optional): string that values in ['LN', 'GN1', 'BN', 'LMN'] and that allows to
-            choose from LayerNormalization, GroupNormalization(groups=1, ...), BatchNormalization
-            or LayerMadNormalization layers respectively in the block. Defaults to 'LN'.
-        softmax (str, optional): string with values in ['softmax', 'softmax2'] that allows to choose
-            between softmax and softmax2 activation in attention. Defaults to 'softmax'.
-        mlp_act (str, optional): string that values in ['GeLU', 'ReLUx', 'swish'] and that allows to
-            choose from GeLU, ReLUx or swish activation in the MLP block. Defaults to "GeLU".
-
-    Returns:
-        (tf.Tensor, (tf.Tensor, tf.Tensor)): block outputs and (attention softmaxed scores, the
-        normalized sum of inputs and attention outputs)
-    """
-    x = norm_to_layer(norm)(epsilon=1e-6, name=f"{name}/LayerNorm_0")(inputs)
-    x, weights = multi_head_attention(x,
-                                      num_heads=num_heads,
-                                      hidden_size=hidden_size,
-                                      name=f"{name}/MultiHeadDotProductAttention_1",
-                                      softmax=softmax
-                                      )
-    x = Dropout(dropout)(x)
-    x_norm2 = Add(name=f"{name}/add_1")([x, inputs])
-    y = norm_to_layer(norm)(epsilon=1e-6, name=f"{name}/LayerNorm_2")(x_norm2)
-    y = mlp_block(y, mlp_dim, dropout, f"{name}/MlpBlock", mlp_act)
-    outputs = Add(name=f"{name}/add_2")([x_norm2, y])
-    return outputs, (weights, x_norm2)
-
-
 def conv_transpose_block(inputs,
                          filters,
                          kernel_size,
@@ -574,25 +435,6 @@ def yolo_head_block(x, num_boxes, classes, filters=1024):
     return x
 
 
-def vit_extract_feature_map(y, feat_shape, num_non_patch=1):
-    """Add a ExtractToken + Reshape layers to convert the plain ViT output into a feature map.
-
-    All tokens will be extracted except those considered as class tokens (``num_non_patch``)
-
-    Args:
-        y (:obj:`tf.Tensor`): output of ViT classifier model.
-        feat_shape (tuple of int): height/width desired output size
-        num_non_patch (int, optional): number of non-patch tokens to exclude on the final output.
-            Defaults to 1.
-
-    Returns:
-        :obj:`keras.Model`: ViT with new layers
-    """
-    y = ExtractToken(name="extract_features", token=list(range(num_non_patch, y.shape[1])))(y)
-    y = Reshape(target_shape=(*feat_shape, y.shape[-1]), name="features")(y)
-    return y
-
-
 def get_ortho_polynomials(length, degrees, alpha, beta):
     """ Generate the set of Jacobi orthogonal polynomials with shape (degrees + 1, length)
 
@@ -726,7 +568,7 @@ def conv3d_block(inputs,
     # If it's a temporal Conv3d with a same padding, convert it to a one sided-left padding,
     # by adding a ZeroPadding3D layer and setting the Conv3D padding to "valid"
     if kernel_size[0] != 1 and kwargs.get('padding', 'valid') == 'same':
-        padding_layer = tf.keras.layers.ZeroPadding3D(
+        padding_layer = keras.layers.ZeroPadding3D(
             padding=((kernel_size[0] - 1, 0), (0, 0), (0, 0)))
         inputs = padding_layer(inputs)
         kwargs['padding'] = 'valid'
@@ -745,17 +587,14 @@ def conv3d_block(inputs,
         if reg_factor:
             if normalize_reg:
                 reg_factor /= np.prod(x.shape[1:])
-            x = tf.keras.layers.ActivityRegularization(l1=reg_factor)(x)
+            x = keras.layers.ActivityRegularization(l1=reg_factor)(x)
     return x
 
 
-def spatiotemporal_block(inputs, in_channels, med_channels, out_channels, t_kernel_size,
-                         t_depthwise, s_depthwise, index, reg_factor=None, normalize_reg=False,
-                         use_pleiades=False, degrees=None, alpha=None, beta=None):
-    """ Add a spatiotemporal block to the inputs.
-
-    The spatio-temporal block consists of a temporal convolution (potentially separable) followed by
-    a spatial convolution (potentially separable).
+def temporal_block(inputs, in_channels, out_channels, t_kernel_size,
+                   depthwise, index, reg_factor=None, normalize_reg=False,
+                   use_pleiades=False, degrees=None, alpha=None, beta=None):
+    """ Add a temporal block to the inputs.
 
     Note that the depthwise layers are implemented as Conv3D with groups=filters because TensorFlow
     does not have a DepthwiseConv3D layer.
@@ -763,18 +602,16 @@ def spatiotemporal_block(inputs, in_channels, med_channels, out_channels, t_kern
     Args:
         inputs (tf.Tensor): input tensor
         in_channels (int): input channels
-        med_channels (int): middle channels (channels after the temporal conv layer)
-        out_channels (int): output channels (channels after the spatial conv layer)
+        out_channels (int): output channels
         t_kernel_size (int): the temporal kernel size
-        t_depthwise (bool): whether the temporal layer is dw_separable
-        s_depthwise (bool): whether the spatial layer is dw_separable
+        depthwise (bool): whether the temporal layer is dw_separable
         index (int): index of the block
         reg_factor (float, optional): the L1-regularization factor of the ActivityRegularization
             layers that are added after the ReLU layers if reg_factor is not None.
             Defaults to None.
         normalize_reg (bool, optional): if True, normalize the L1-regularization factor.
             Defaults to False.
-        use_pleiades (bool, optional): if True, the first conv3d of the TemporalBlock
+        use_pleiades (bool, optional): if True, the first conv3d of the temporal block
             is a PleiadesLayer. Defaults to False.
         degrees (int, optional): The maximum polynomial degree of the Jacobi matrix. It needs to be
             set if use_pleiades is True. Defaults to None.
@@ -784,11 +621,11 @@ def spatiotemporal_block(inputs, in_channels, med_channels, out_channels, t_kern
             Defaults to None.
 
     Returns:
-        tf.Tensor: output tensor of the spatiotemporal block.
+        tf.Tensor: output tensor of the temporal block.
     """
-    if not t_depthwise:
+    if not depthwise:
         x = conv3d_block(inputs,
-                         med_channels,
+                         out_channels,
                          (t_kernel_size, 1, 1),
                          add_batchnorm=True,
                          relu_activation='ReLU',
@@ -821,16 +658,40 @@ def spatiotemporal_block(inputs, in_channels, med_channels, out_channels, t_kern
                          alpha=alpha,
                          beta=beta)
         x = conv3d_block(x,
-                         med_channels,
+                         out_channels,
                          (1, 1, 1),
                          add_batchnorm=True,
                          relu_activation='ReLU',
                          name=f'convt_pw_{index}',
                          reg_factor=reg_factor,
                          normalize_reg=normalize_reg)
+    return x
 
-    if not s_depthwise:
-        x = conv3d_block(x,
+
+def spatial_block(inputs, in_channels, out_channels, depthwise, index, reg_factor=None,
+                  normalize_reg=False):
+    """ Add a spatial block to the inputs.
+
+    Note that the depthwise layers are implemented as Conv3D with groups=filters because TensorFlow
+    does not have a DepthwiseConv3D layer.
+
+    Args:
+        inputs (tf.Tensor): input tensor
+        in_channels (int): input channels
+        out_channels (int): output channels
+        depthwise (bool): whether the spatial layer is dw_separable
+        index (int): index of the block
+        reg_factor (float, optional): the L1-regularization factor of the ActivityRegularization
+            layers that are added after the ReLU layers if reg_factor is not None.
+            Defaults to None.
+        normalize_reg (bool, optional): if True, normalize the L1-regularization factor.
+            Defaults to False.
+
+    Returns:
+        tf.Tensor: output tensor of the spatial block.
+    """
+    if not depthwise:
+        x = conv3d_block(inputs,
                          out_channels,
                          (1, 3, 3),
                          add_batchnorm=True,
@@ -843,14 +704,14 @@ def spatiotemporal_block(inputs, in_channels, med_channels, out_channels, t_kern
                          normalize_reg=normalize_reg)
     else:
         # This is a DepthwiseConv3D (groups=filters)
-        x = conv3d_block(x,
-                         med_channels,
+        x = conv3d_block(inputs,
+                         in_channels,
                          (1, 3, 3),
                          add_batchnorm=True,
                          relu_activation='ReLU',
                          strides=(1, 2, 2),
                          padding='same',
-                         groups=med_channels,
+                         groups=in_channels,
                          use_bias=False,
                          name=f'convs_dw_{index}',
                          reg_factor=reg_factor,
@@ -864,3 +725,58 @@ def spatiotemporal_block(inputs, in_channels, med_channels, out_channels, t_kern
                          reg_factor=reg_factor,
                          normalize_reg=normalize_reg)
     return x
+
+
+def spatiotemporal_block(inputs, in_channels, med_channels, out_channels, t_kernel_size,
+                         t_depthwise, s_depthwise, index, temporal_first=True, reg_factor=None,
+                         normalize_reg=False, use_pleiades=False, degrees=None, alpha=None,
+                         beta=None):
+    """ Add a spatiotemporal block to the inputs.
+
+    The spatio-temporal block consists of a temporal convolution (potentially separable) followed by
+    a spatial convolution (potentially separable) or the inverse.
+
+    Note that the depthwise layers are implemented as Conv3D with groups=filters because TensorFlow
+    does not have a DepthwiseConv3D layer.
+
+    Args:
+        inputs (tf.Tensor): input tensor
+        in_channels (int): input channels
+        med_channels (int): intermediate channels between blocks
+        out_channels (int): output channels
+        t_kernel_size (int): the temporal kernel size
+        t_depthwise (bool): whether the temporal layer is dw_separable
+        s_depthwise (bool): whether the spatial layer is dw_separable
+        index (int): index of the block
+        temporal_first (bool, optional): if True, the first block is a temporal block.
+            Defaults to True.
+        reg_factor (float, optional): the L1-regularization factor of the ActivityRegularization
+            layers that are added after the ReLU layers if reg_factor is not None.
+            Defaults to None.
+        normalize_reg (bool, optional): if True, normalize the L1-regularization factor.
+            Defaults to False.
+        use_pleiades (bool, optional): if True, the first conv3d of the TemporalBlock
+            is a PleiadesLayer. Defaults to False.
+        degrees (int, optional): The maximum polynomial degree of the Jacobi matrix. It needs to be
+            set if use_pleiades is True. Defaults to None.
+        alpha (int, optional): The alpha Jacobi parameter. It needs to be set if
+            use_pleiades is True. Defaults to None.
+        beta (int, optional): The beta Jacobi parameter. It needs to be set if use_pleiades is True.
+            Defaults to None.
+
+    Returns:
+        tf.Tensor: output tensor of the spatiotemporal block.
+    """
+    if temporal_first:
+        x = temporal_block(inputs, in_channels, med_channels, t_kernel_size,
+                           t_depthwise, index, reg_factor=reg_factor, normalize_reg=normalize_reg,
+                           use_pleiades=use_pleiades, degrees=degrees, alpha=alpha, beta=beta)
+        x = spatial_block(x, med_channels, out_channels, s_depthwise, index, reg_factor=reg_factor,
+                          normalize_reg=normalize_reg)
+    else:
+        x = spatial_block(inputs, in_channels, med_channels, s_depthwise, index,
+                          reg_factor=reg_factor, normalize_reg=normalize_reg)
+        x = temporal_block(x, med_channels, out_channels, t_kernel_size,
+                           t_depthwise, index, reg_factor=reg_factor, normalize_reg=normalize_reg,
+                           use_pleiades=use_pleiades, degrees=degrees, alpha=alpha, beta=beta)
+    return x
