@@ -19,8 +19,8 @@ Training script for MNIST models.
 """
 
 import os
-from keras.datasets import mnist
-from keras.losses import SparseCategoricalCrossentropy
+from tf_keras.datasets import mnist
+from tf_keras.losses import SparseCategoricalCrossentropy
 
 from cnn2snn import convert
 
@@ -32,9 +32,12 @@ from ..extract import extract_samples
 from ..model_io import load_model
 
 
-def get_data():
+def get_data(dtype='uint8'):
     """ Loads MNIST data.
 
+    Args:
+        dtype (str, optional): input data type. Defaults to 'uint8'.
+
     Returns:
         tuple: train data, train labels, test data and test labels
     """
@@ -48,7 +51,8 @@ def get_data():
     x_test = x_test.astype("float32")
     x_test = np.reshape(x_test, (-1, 28, 28, 1))
 
-    return x_train, y_train, x_test, y_test
+    return (x_train.astype(dtype), y_train.astype(np.int32),
+            x_test.astype(dtype), y_test.astype(np.int32))
 
 
 def train_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
@@ -97,7 +101,7 @@ def main():
         # Evaluate model accuracy
         if args.akida:
             model_ak = convert(model)
-            accuracy = model_ak.evaluate(x_test.astype('uint8'), y_test)
+            accuracy = model_ak.evaluate(x_test, y_test)
             print(f"Accuracy: {accuracy}")
         else:
             evaluate_model(model, x_test, y=y_test)
