@@ -20,10 +20,11 @@ PointNet++ model definition for ModelNet40 classification.
 
 __all__ = ["pointnet_plus_modelnet40", "pointnet_plus_modelnet40_pretrained"]
 
-from keras import layers, Model, regularizers
+import tensorflow as tf
+from tf_keras import layers, Model, regularizers
 
 from .pointnet_utils import get_reshape_factor
-from ..layer_blocks import conv_block, dense_block, act_to_layer
+from ..layer_blocks import conv_block, act_to_layer
 from ..utils import fetch_file, get_params_by_version
 from ..model_io import load_model, get_model_path, get_default_bitwidth
 
@@ -69,7 +70,7 @@ def pointnet_plus_modelnet40(selected_points=64, features=3, knn_points=32, clas
     input_shape = (knn_points // reshape_factor,
                    selected_points * reshape_factor, features)
 
-    inputs = layers.Input(shape=input_shape, name="input")
+    inputs = layers.Input(shape=input_shape, name="input", dtype=tf.uint8)
     base_filter_num = round(32 * alpha)
     reg = regularizers.l1_l2(1e-7, 1e-7)
 
@@ -153,23 +154,35 @@ def pointnet_plus_modelnet40(selected_points=64, features=3, knn_points=32, clas
                    filters=base_filter_num * 16,
                    name='block_5/conv_1',
                    kernel_size=(1, 1),
-                   pooling='global_avg',
                    post_relu_gap=post_relu_gap,
                    padding='same',
                    add_batchnorm=True)
 
     # Block 6
-    x = layers.Reshape((1, 1, x.shape[-1]))(x)
-    x = dense_block(x,
-                    units=base_filter_num * 16,
-                    name='fc_1',
-                    relu_activation=relu_activation,
-                    add_batchnorm=True)
-    x = dense_block(x,
-                    units=base_filter_num * 8,
-                    name='fc_2',
-                    relu_activation=relu_activation,
-                    add_batchnorm=True)
+    x = conv_block(x,
+                   filters=base_filter_num * 4,
+                   name='block_6/conv_1',
+                   kernel_size=(1, 1),
+                   post_relu_gap=post_relu_gap,
+                   padding='same',
+                   add_batchnorm=True,
+                   relu_activation=False)
+    x = act_to_layer(relu_activation, activity_regularizer=reg, name='block_6/conv_1/relu_1')(x)
+
+    # Block 7
+    x = conv_block(x,
+                   filters=base_filter_num * 2,
+                   name='block_7/conv_1',
+                   kernel_size=(1, 1),
+                   pooling=None if post_relu_gap else 'global_avg',
+                   post_relu_gap=post_relu_gap,
+                   padding='same',
+                   add_batchnorm=True,
+                   relu_activation=False)
+    x = act_to_layer(relu_activation, activity_regularizer=reg, name='block_7/conv_1/relu_1')(x)
+    if post_relu_gap:
+        x = layers.GlobalAveragePooling2D(keepdims=True, name='gap_1')(x)
+
     x = layers.Dense(classes, activation=None, name="dense")(x)
     act_function = 'softmax' if classes > 1 else 'sigmoid'
     x = layers.Activation(act_function, name=f'act_{act_function}')(x)
@@ -199,11 +212,11 @@ def pointnet_plus_modelnet40_pretrained(quantized=True, bitwidth=None):
             model_name_v1 = 'pointnet_plus_modelnet40_iq8_wq4_aq4.h5'
             file_hash_v1 = '8c6cb08a72909a50e2792f9b0b52c17e9972a9a42e8ace11443e811c18b6573c'
             model_name_v2 = 'pointnet_plus_modelnet40_i8_w4_a4.h5'
-            file_hash_v2 = 'ccb8acffa0372f14a43597c833e93e97ab9c987f8481834b5609c3d8512b5e0c'
+            file_hash_v2 = '2f80961966bc9609c187d670f6c716632d4a10b6f9e7f96ab0a648b8f69c638b'
         elif bitwidth == 8:
             model_name_v1, file_hash_v1 = None, None
             model_name_v2 = 'pointnet_plus_modelnet40_i8_w8_a8.h5'
-            file_hash_v2 = 'e97664416fb2e8b66573e0718d4107d813ba87472abb24ab0bf6aeb511e3042e'
+            file_hash_v2 = '470feb4e68297713a6adf3131e6a5356d2ddc24a55fa6a7f94668bcd3f9b407b'
         else:
             raise ValueError(f"bitwidth={bitwidth} is not available, use bitwidth=4 or 8 for this"
                              " model.")
@@ -211,7 +224,7 @@ def pointnet_plus_modelnet40_pretrained(quantized=True, bitwidth=None):
         model_name_v1 = 'pointnet_plus_modelnet40.h5'
         file_hash_v1 = '1499e8d629642c0f67436bdc8ba7d883c2f1cc1f5993a758588fa177a3fc585c'
         model_name_v2 = 'pointnet_plus_modelnet40.h5'
-        file_hash_v2 = '4c9ce75c9acc9a98070ba3a385f388e3672a534972f6e921e2746b1b8e451e92'
+        file_hash_v2 = '4ee532f97552fc121fbd82ea74167c346ccd8b463136fa14fb476ad422834c3c'
 
     model_path, model_name, file_hash = get_model_path("pointnet_plus", model_name_v1, file_hash_v1,
                                                        model_name_v2, file_hash_v2)
