@@ -21,8 +21,9 @@ ModelNet40 model training script.
 import os
 import argparse
 import numpy as np
+import tensorflow as tf
 
-from keras.callbacks import LearningRateScheduler
+from tf_keras.callbacks import LearningRateScheduler
 
 from cnn2snn import convert
 
@@ -34,7 +35,7 @@ from ..extract import extract_samples
 from ..model_io import load_model
 
 
-def get_data(batch_size, selected_points, knn_points):
+def get_data(batch_size, selected_points, knn_points, dtype=tf.uint8):
     """ Loads data.
 
     Args:
@@ -43,6 +44,7 @@ def get_data(batch_size, selected_points, knn_points):
         knn_points (int): number of points to include in each localised group.
             Must be a power of 2, and ideally an integer square (so 64, or 16
             for a deliberately small network, or 256 for large).
+        dtype (tf.dtypes.DType): input data type. Defaults to tf.uint8.
 
     Returns:
         tf.Dataset, tf.Dataset: train and test point with data augmentation
@@ -59,7 +61,8 @@ def get_data(batch_size, selected_points, knn_points):
                                                test_labels,
                                                batch_size=batch_size,
                                                selected_points=selected_points,
-                                               knn_points=knn_points)
+                                               knn_points=knn_points,
+                                               dtype=dtype)
 
     return train_dataset, test_dataset
 
