@@ -24,8 +24,8 @@ import math
 import numpy as np
 import tensorflow as tf
 
-from keras.callbacks import Callback
-from tensorflow.keras.optimizers.schedules import LearningRateSchedule
+from tf_keras.callbacks import Callback
+from tf_keras.optimizers.schedules import LearningRateSchedule
 
 
 class _Annealer:
