@@ -22,9 +22,10 @@ import os
 import argparse
 
 import tensorflow as tf
+import tf_keras as keras
 import numpy as np
-from keras.metrics import BinaryIoU
-from keras.losses import BinaryCrossentropy
+from tf_keras.metrics import BinaryIoU
+from tf_keras.losses import BinaryCrossentropy
 
 from cnn2snn import convert
 
@@ -65,12 +66,13 @@ def _train_eval_split(x, y, validation_split=0.2, random_state=None):
     return x_train, x_val, y_train, y_val
 
 
-def get_data(path, batch_size):
+def get_data(path, batch_size, dtype=tf.uint8):
     """ Loads Portrait128 data.
 
     Args:
         path (str): path to npy data
         batch_size (int): the batch size
+        dtype (tf.dtypes.DType, optional): input data type. Defaults to tf.uint8.
 
     Returns:
         tuple: train dataset, validation dataset, steps per epoch and validation step
@@ -83,12 +85,17 @@ def get_data(path, batch_size):
                                                        y,
                                                        validation_split=0.2,
                                                        random_state=seed)
-    data_augmentation = tf.keras.Sequential([
-        tf.keras.layers.RandomFlip("horizontal", seed=seed),
-        tf.keras.layers.RandomTranslation(height_factor=0.1, width_factor=0.1, seed=seed),
-        tf.keras.layers.RandomZoom(0.2, seed=seed),
+    data_augmentation = keras.Sequential([
+        keras.layers.RandomFlip("horizontal", seed=seed),
+        keras.layers.RandomTranslation(height_factor=0.1, width_factor=0.1, seed=seed),
+        keras.layers.RandomZoom(0.2, seed=seed),
     ])
 
+    def cast_data(image, label):
+        image = tf.cast(image, dtype)
+        label = tf.cast(label, tf.int32)
+        return image, label
+
     def data_generator(images, masks):
         for image, mask in zip(images, masks):
             yield image, mask
@@ -106,16 +113,16 @@ def get_data(path, batch_size):
     train_dataset = tf.data.Dataset.from_generator(
         generator=lambda: data_generator(x_train, y_train),
         output_signature=(
-            tf.TensorSpec(shape=x_train.shape[1:], dtype=tf.float32),
-            tf.TensorSpec(shape=y_train.shape[1:], dtype=tf.float32)
+            tf.TensorSpec(shape=x_train.shape[1:], dtype=dtype),
+            tf.TensorSpec(shape=y_train.shape[1:], dtype=dtype)
         )
     )
 
     validation_dataset = tf.data.Dataset.from_generator(
         generator=lambda: data_generator(x_val, y_val),
         output_signature=(
-            tf.TensorSpec(shape=x_val.shape[1:], dtype=tf.float32),
-            tf.TensorSpec(shape=y_val.shape[1:], dtype=tf.float32)
+            tf.TensorSpec(shape=x_val.shape[1:], dtype=dtype),
+            tf.TensorSpec(shape=y_val.shape[1:], dtype=dtype)
         )
     )
 
@@ -123,11 +130,13 @@ def get_data(path, batch_size):
     train_batches = (train_dataset
                      .shuffle(SHUFFLE_BUFFER_SIZE)
                      .map(apply_data_augmentation)
+                     .map(cast_data, num_parallel_calls=tf.data.AUTOTUNE)
                      .batch(batch_size)
                      .repeat()
                      .prefetch(buffer_size=tf.data.experimental.AUTOTUNE))
 
-    validation_batches = validation_dataset.batch(batch_size)
+    validation_batches = validation_dataset.map(
+        cast_data, num_parallel_calls=tf.data.AUTOTUNE).batch(batch_size)
 
     steps_per_epoch = len(x_train) // batch_size
     val_steps = len(x_val) // batch_size
@@ -177,7 +186,7 @@ def evaluate_akida_model(model, val_ds, val_steps):
 
     for _ in range(val_steps):
         batch, label_batch = next(iter(val_ds))
-        pots_batch = model.predict(batch.numpy().astype('uint8'))
+        pots_batch = model.predict(batch.numpy())
 
         if labels is None:
             labels = label_batch
@@ -185,14 +194,14 @@ def evaluate_akida_model(model, val_ds, val_steps):
         else:
             labels = np.concatenate((labels, label_batch))
             pots = np.concatenate((pots, pots_batch))
-    m_binary_iou = tf.keras.metrics.BinaryIoU(target_class_ids=[0, 1], threshold=0)
+    m_binary_iou = keras.metrics.BinaryIoU(target_class_ids=[0, 1], threshold=0)
     m_binary_iou.update_state(labels, pots)
     binary_iou = m_binary_iou.result().numpy()
 
-    m_accuracy = tf.keras.metrics.Accuracy()
+    m_accuracy = keras.metrics.Accuracy()
     m_accuracy.update_state(labels, pots > 0)
     accuracy = m_accuracy.result().numpy()
-    print(f"Akida BinaryIoU/pixel accuracy: {binary_iou:.4f}/{100*accuracy:.2f}%")
+    print(f"Akida BinaryIoU/pixel accuracy: {binary_iou:.4f}/{100 * accuracy:.2f}%")
 
 
 def main():
