@@ -23,10 +23,10 @@ import tempfile
 import argparse
 import numpy as np
 
-from keras.preprocessing.image import DirectoryIterator
-from keras.optimizers.legacy import Adam
-from keras.layers import Activation
-from keras.callbacks import ModelCheckpoint
+from tf_keras.preprocessing.image import DirectoryIterator
+from tf_keras.optimizers.legacy import Adam
+from tf_keras.layers import Activation
+from tf_keras.callbacks import ModelCheckpoint
 
 
 def compile_model(model,
@@ -127,13 +127,7 @@ def evaluate_akida_model(model, x, activation):
         if not isinstance(batch, np.ndarray):
             batch = batch.numpy()
 
-        # Retrieve input_signed value: cannot use getattr here because LayerParams does not
-        # implement a default value.
-        input_signed = 'input_signed' in dir(model.get_layer(0).parameters)
-        if input_signed:
-            input_signed = model.get_layer(0).parameters.input_signed
-        type = 'int8' if input_signed else 'uint8'
-        pots_batch = model.predict(batch.astype(type))
+        pots_batch = model.predict(batch)
 
         if labels is None:
             labels = label_batch
