@@ -22,8 +22,8 @@ __all__ = ["unfuse_sepconv2d"]
 
 from copy import deepcopy
 
-from keras.models import Sequential
-from keras.layers import SeparableConv2D
+from tf_keras.models import Sequential
+from tf_keras.layers import SeparableConv2D
 from quantizeml.models.utils import apply_weights_to_model
 from quantizeml.models.transforms.transforms_utils import (
     get_layer_index, get_layers_by_type, update_inbound)
