@@ -20,7 +20,7 @@ Training script for UTKFace model.
 import os
 import numpy as np
 
-from keras.callbacks import LearningRateScheduler
+from tf_keras.callbacks import LearningRateScheduler
 
 from cnn2snn import convert
 
@@ -31,9 +31,12 @@ from ..model_io import load_model
 from .preprocessing import load_data
 
 
-def get_data():
+def get_data(dtype='uint8'):
     """ Loads UTKFace data.
 
+    Args:
+        dtype (str, optional): input data type. Defaults to 'uint8'.
+
     Returns:
         np.array, np.array, np.array, np.array: train set, train labels, test
             set and test labels
@@ -41,7 +44,8 @@ def get_data():
     # Load the dataset
     x_train, y_train, x_test, y_test = load_data()
 
-    return x_train.astype('float32'), y_train, x_test.astype('float32'), y_test
+    return (x_train.astype(dtype), y_train.astype('int32'), x_test.astype(dtype),
+            y_test.astype('int32'))
 
 
 def train_model(model, x_train, y_train, x_test, y_test, epochs, batch_size):
@@ -100,7 +104,7 @@ def main():
         # Evaluate model accuracy
         if args.akida:
             model_ak = convert(model)
-            y = model_ak.predict(x_test.astype(np.uint8))
+            y = model_ak.predict(x_test)
             mae = np.sum(np.abs(y_test.squeeze() - y.squeeze())) / len(y_test)
             print("Validation accuracy: {0:.4f}".format(mae))
         else:
